@@ -1,11 +1,8 @@
+import threading
 from functools import (
     wraps,
 )
 
-from m3_legacy.middleware import (
-    get_thread_data,
-)
-
 
 def log_query(log_query_name):
     """
@@ -17,7 +14,7 @@ def log_query(log_query_name):
     def inner(action):
         @wraps(action)
         def wrapper(self, request, context, *args, **kwargs):
-            thread_locals = get_thread_data()
+            thread_locals = threading.local()
 
             setattr(thread_locals, 'log_query', log_query_name)
 
