@@ -1,8 +1,5 @@
 import copy
 import inspect
-from functools import (
-    lru_cache,
-)
 from itertools import (
     chain,
 )
@@ -569,7 +566,6 @@ class ModelEnum(Model, metaclass=ModelEnumMetaclass):
         abstract = True
 
     @classmethod
-    @lru_cache()
     def get_enum_data(cls) -> Dict[str, ModelEnumValue]:
         """
         Возвращает данные перечисления в виде словаря.
@@ -599,7 +595,6 @@ class ModelEnum(Model, metaclass=ModelEnumMetaclass):
         return enum_data
 
     @classmethod
-    @lru_cache()
     def get_model_enum_values(cls) -> List[ModelEnumValue]:
         """
         Получение значений модели перечисления.
@@ -607,7 +602,6 @@ class ModelEnum(Model, metaclass=ModelEnumMetaclass):
         return list(cls.get_enum_data().values())
 
     @classmethod
-    @lru_cache()
     def get_model_enum_keys(cls) -> List[str]:
         """
         Получение значений модели перечисления.
