@@ -7,6 +7,9 @@ from django.conf import (
 LOG_PATH = getattr(settings, 'LOG_PATH', '/tmp')
 # Включение логирования SQL-запросов
 SQL_LOG = getattr(settings, 'SQL_LOG', False)
+# Логирование SQL-запросов только зарегистрированных экшенов, функций при помощи декоратора
+# m3_db_utils.decorators.log_query
+SQL_LOG_ONLY_REGISTERED = getattr(settings, 'SQL_LOG_ONLY_REGISTERED', False)
 # Включение дополнительного вывода трейса с местом отправки запроса
 SQL_LOG_WITH_STACK_TRACE = getattr(settings, 'SQL_LOG_WITH_STACK_TRACE', False)
 # Запрос форматируется со значением полей
@@ -15,7 +18,3 @@ SQL_LOG_WITH_PARAMETERS = getattr(settings, 'SQL_LOG_WITH_PARAMETERS', False)
 SQL_LOG_MAX_SIZE = getattr(settings, 'SQL_LOG_MAX_SIZE', 25_000)
 # Включает форматирование выводимых SQL-запросов
 SQL_LOG_REINDENT = getattr(settings, 'SQL_LOG_REINDENT', False)
-
-# Включение логирования запросов экшенов, помеченных декоратором log_query. Не требует включенного DEBUG-режима и
-# включенного SQL_LOG
-SQL_LOG_QUERY = getattr(settings, 'SQL_LOG_QUERY', False)
